package org.apache.bcel.classfile;

import java.io.DataOutputStream;
import java.io.IOException;
import java.io.DataInput;

public final class ModuleMainClass extends Attribute
{
    private int mainClassIndex;
    
    ModuleMainClass(final int nameIndex, final int length, final DataInput input, final ConstantPool constantPool) throws IOException {
        this(nameIndex, length, 0, constantPool);
        this.mainClassIndex = input.readUnsignedShort();
    }
    
    public ModuleMainClass(final int nameIndex, final int length, final int mainClassIndex, final ConstantPool constantPool) {
        super((byte)26, nameIndex, length, constantPool);
        this.mainClassIndex = mainClassIndex;
    }
    
    public ModuleMainClass(final ModuleMainClass c) {
        this(c.getNameIndex(), c.getLength(), c.getHostClassIndex(), c.getConstantPool());
    }
    
    @Override
    public void accept(final Visitor v) {
        v.visitModuleMainClass(this);
    }
    
    @Override
    public Attribute copy(final ConstantPool constantPool) {
        final ModuleMainClass c = (ModuleMainClass)this.clone();
        c.setConstantPool(constantPool);
        return c;
    }
    
    @Override
    public void dump(final DataOutputStream file) throws IOException {
        super.dump(file);
        file.writeShort(this.mainClassIndex);
    }
    
    public int getHostClassIndex() {
        return this.mainClassIndex;
    }
    
    public void setHostClassIndex(final int mainClassIndex) {
        this.mainClassIndex = mainClassIndex;
    }
    
    @Override
    public String toString() {
        final StringBuilder buf = new StringBuilder();
        buf.append("ModuleMainClass: ");
        final String className = super.getConstantPool().getConstantString(this.mainClassIndex, (byte)7);
        buf.append(Utility.compactClassName(className, false));
        return buf.toString();
    }
}
